# Translation of Source Code for DocFX Websites

This tool translates DocFX's Markdown and Yaml source code to foreign languages, preserving markup sintax.

Install Python 3, then install this package with the following command:

```pip install tradocs```

Type ```tradocs``` on the command line to see the options.

Powered by [Yandex.Translate](http://translate.yandex.com)